summaryrefslogtreecommitdiff
path: root/nuttx/binfmt
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-31 17:04:02 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-31 17:04:02 -0600
commit7482b7ad0f60724e593a8919783444ef79f4c79e (patch)
tree396e7019c35eb0f49f430c1132972eedc292a752 /nuttx/binfmt
parent2ad3a4c2a2b56a721180faa3c689110d86d90359 (diff)
downloadpx4-nuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.tar.gz
px4-nuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.tar.bz2
px4-nuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.zip
Rename kfree to kmm_free for consistency with other naming conventions
Diffstat (limited to 'nuttx/binfmt')
-rw-r--r--nuttx/binfmt/binfmt_exec.c4
-rw-r--r--nuttx/binfmt/binfmt_execmodule.c2
-rw-r--r--nuttx/binfmt/binfmt_exepath.c6
-rw-r--r--nuttx/binfmt/binfmt_loadmodule.c2
-rw-r--r--nuttx/binfmt/binfmt_schedunload.c6
-rw-r--r--nuttx/binfmt/libelf/libelf_uninit.c4
-rw-r--r--nuttx/binfmt/libnxflat/libnxflat_addrenv.c6
-rw-r--r--nuttx/binfmt/pcode.c4
8 files changed, 17 insertions, 17 deletions
diff --git a/nuttx/binfmt/binfmt_exec.c b/nuttx/binfmt/binfmt_exec.c
index 71f8c9a85..b8680c004 100644
--- a/nuttx/binfmt/binfmt_exec.c
+++ b/nuttx/binfmt/binfmt_exec.c
@@ -124,7 +124,7 @@ int exec(FAR const char *filename, FAR char * const *argv,
if (ret < 0)
{
bdbg("ERROR: Failed to load program '%s'\n", filename);
- kfree(bin);
+ kmm_free(bin);
return ERROR;
}
@@ -143,7 +143,7 @@ int exec(FAR const char *filename, FAR char * const *argv,
bdbg("ERROR: Failed to execute program '%s'\n", filename);
sched_unlock();
unload_module(bin);
- kfree(bin);
+ kmm_free(bin);
return ERROR;
}
diff --git a/nuttx/binfmt/binfmt_execmodule.c b/nuttx/binfmt/binfmt_execmodule.c
index 34e8f30ac..a2bcd2e41 100644
--- a/nuttx/binfmt/binfmt_execmodule.c
+++ b/nuttx/binfmt/binfmt_execmodule.c
@@ -257,7 +257,7 @@ errout_with_stack:
goto errout;
errout_with_tcb:
- kfree(tcb);
+ kmm_free(tcb);
errout:
set_errno(err);
bdbg("returning errno: %d\n", err);
diff --git a/nuttx/binfmt/binfmt_loadmodule.c b/nuttx/binfmt/binfmt_loadmodule.c
index 5ff7f7535..636c537d9 100644
--- a/nuttx/binfmt/binfmt_loadmodule.c
+++ b/nuttx/binfmt/binfmt_loadmodule.c
@@ -226,7 +226,7 @@ int load_module(FAR struct binary_s *bin)
/* Free the allocated fullpath */
- kfree(fullpath);
+ kmm_free(fullpath);
/* Break out of the loop with ret == OK on success */
diff --git a/nuttx/binfmt/libelf/libelf_uninit.c b/nuttx/binfmt/libelf/libelf_uninit.c
index 3ec6f6c61..fb673e739 100644
--- a/nuttx/binfmt/libelf/libelf_uninit.c
+++ b/nuttx/binfmt/libelf/libelf_uninit.c
@@ -111,13 +111,13 @@ int elf_freebuffers(struct elf_loadinfo_s *loadinfo)
if (loadinfo->shdr)
{
- kfree((FAR void *)loadinfo->shdr);
+ kmm_free((FAR void *)loadinfo->shdr);
loadinfo->shdr = NULL;
}
if (loadinfo->iobuffer)
{
- kfree((FAR void *)loadinfo->iobuffer);
+ kmm_free((FAR void *)loadinfo->iobuffer);
loadinfo->iobuffer = NULL;
loadinfo->buflen = 0;
}
diff --git a/nuttx/binfmt/libnxflat/libnxflat_addrenv.c b/nuttx/binfmt/libnxflat/libnxflat_addrenv.c
index d5abc452d..7378c2438 100644
--- a/nuttx/binfmt/libnxflat/libnxflat_addrenv.c
+++ b/nuttx/binfmt/libnxflat/libnxflat_addrenv.c
@@ -157,7 +157,7 @@ errout_with_addrenv:
loadinfo->addrenv = 0;
errout_with_dspace:
- kfree(dspace);
+ kmm_free(dspace);
return ret;
#else
/* Allocate (and zero) memory to hold the ELF image */
@@ -165,7 +165,7 @@ errout_with_dspace:
dspace->region = (FAR uint8_t *)kumm_zalloc(envsize);
if (!dspace->region)
{
- kfree(dspace);
+ kmm_free(dspace);
return -ENOMEM;
}
@@ -227,7 +227,7 @@ void nxflat_addrenv_free(FAR struct nxflat_loadinfo_s *loadinfo)
/* Now destroy the D-Space container */
DEBUGASSERT(dspace->crefs == 1);
- kfree(dspace);
+ kmm_free(dspace);
loadinfo->dspace = NULL;
}
}
diff --git a/nuttx/binfmt/pcode.c b/nuttx/binfmt/pcode.c
index b2a243cb0..b2cac5880 100644
--- a/nuttx/binfmt/pcode.c
+++ b/nuttx/binfmt/pcode.c
@@ -267,7 +267,7 @@ static int pcode_proxy(int argc, char **argv)
if (ret < 0)
{
bdbg("ERROR: on_exit failed: %d\n", get_errno());
- kfree(fullpath);
+ kmm_free(fullpath);
return EXIT_FAILURE;
}
@@ -277,7 +277,7 @@ static int pcode_proxy(int argc, char **argv)
/* We no longer need the fullpath */
- kfree(fullpath);
+ kmm_free(fullpath);
/* Check the result of the interpretation */
diff --git a/nuttx/binfmt/binfmt_exepath.c b/nuttx/binfmt/binfmt_exepath.c
index 5da242b4c..af69499d1 100644
--- a/nuttx/binfmt/binfmt_exepath.c
+++ b/nuttx/binfmt/binfmt_exepath.c
@@ -161,7 +161,7 @@ EXEPATH_HANDLE exepath_init(void)
* is marked executable).
*
* NOTE: The string pointer return in the success case points to allocated
* memory. This memory must be freed by the called by calling kfree().
*
* NULL is returned if no path is found to any file with the provided
* 'relpath' from any absolute path in the PATH variable. In this case,
@@ -254,7 +254,7 @@ FAR char *exepath_next(EXEPATH_HANDLE handle, FAR const char *relpath)
* continue to try the next path.
*/
- kfree(fullpath);
+ kmm_free(fullpath);
}
/* We will not get here */
@@ -279,7 +279,7 @@ FAR char *exepath_next(EXEPATH_HANDLE handle, FAR const char *relpath)
void exepath_release(EXEPATH_HANDLE handle)
{
- kfree(handle);
+ kmm_free(handle);
}
#endif /* !CONFIG_BINFMT_DISABLE && CONFIG_BINFMT_EXEPATH */
@@ -161,7 +161,7 @@ EXEPATH_HANDLE exepath_init(void)
*
* NOTE: The string pointer return in the success case points to allocated
- * memory. This memory must be freed by the called by calling kfree().
+ * memory. This memory must be freed by the called by calling kmm_free().
*
* NULL is returned if no path is found to any file with the provided
diff --git a/nuttx/binfmt/binfmt_schedunload.c b/nuttx/binfmt/binfmt_schedunload.c
index a3f6f9cc1..cedd940c6 100644
--- a/nuttx/binfmt/binfmt_schedunload.c
+++ b/nuttx/binfmt/binfmt_schedunload.c
@@ -188,7 +188,7 @@ static FAR struct binary_s *unload_list_remove(pid_t pid)
* If CONFIG_SCHED_HAVE_PARENT is defined, this function may be called to
* automatically unload the module when task exits. It assumes that
* bin was allocated with kmalloc() or friends and will also automatically
* free the structure with kfree() when the task exists.
*
* Input Parameter:
* pid - The ID of the task that just exited
@@ -231,7 +231,7 @@ static void unload_callback(int signo, siginfo_t *info, void *ucontext)
/* Free the load structure */
- kfree(bin);
+ kmm_free(bin);
}
/****************************************************************************
@@ -246,7 +246,7 @@ static void unload_callback(int signo, siginfo_t *info, void *ucontext)
* the parent of the newly created task to automatically unload the
* module when the task exits. This assumes that (1) the caller is the
* parent of the created task, (2) that bin was allocated with kmalloc()
* or friends. It will also automatically free the structure with kfree()
* after unloading the module.
*
* Input Parameter:
@@ -188,7 +188,7 @@ static FAR struct binary_s *unload_list_remove(pid_t pid)
* automatically unload the module when task exits. It assumes that
* bin was allocated with kmalloc() or friends and will also automatically
- * free the structure with kfree() when the task exists.
+ * free the structure with kmm_free() when the task exists.
*
* Input Parameter:
@@ -246,7 +246,7 @@ static void unload_callback(int signo, siginfo_t *info, void *ucontext)
* module when the task exits. This assumes that (1) the caller is the
* parent of the created task, (2) that bin was allocated with kmalloc()
- * or friends. It will also automatically free the structure with kfree()
+ * or friends. It will also automatically free the structure with kmm_free()
* after unloading the module.
*